stringtools
===========

.. automodule:: abjad.tools.stringtools

.. only:: html

   Functions
   ---------

   .. autosummary::

      ~abjad.tools.stringtools.add_terminal_newlines.add_terminal_newlines
      ~abjad.tools.stringtools.arg_to_bidirectional_direction_string.arg_to_bidirectional_direction_string
      ~abjad.tools.stringtools.arg_to_bidirectional_lilypond_symbol.arg_to_bidirectional_lilypond_symbol
      ~abjad.tools.stringtools.arg_to_tridirectional_direction_string.arg_to_tridirectional_direction_string
      ~abjad.tools.stringtools.arg_to_tridirectional_lilypond_symbol.arg_to_tridirectional_lilypond_symbol
      ~abjad.tools.stringtools.arg_to_tridirectional_ordinal_constant.arg_to_tridirectional_ordinal_constant
      ~abjad.tools.stringtools.capitalize_string_start.capitalize_string_start
      ~abjad.tools.stringtools.format_input_lines_as_doc_string.format_input_lines_as_doc_string
      ~abjad.tools.stringtools.format_input_lines_as_regression_test.format_input_lines_as_regression_test
      ~abjad.tools.stringtools.is_dash_case_file_name.is_dash_case_file_name
      ~abjad.tools.stringtools.is_dash_case_string.is_dash_case_string
      ~abjad.tools.stringtools.is_lower_camel_case_string.is_lower_camel_case_string
      ~abjad.tools.stringtools.is_snake_case_file_name.is_snake_case_file_name
      ~abjad.tools.stringtools.is_snake_case_file_name_with_extension.is_snake_case_file_name_with_extension
      ~abjad.tools.stringtools.is_snake_case_package_name.is_snake_case_package_name
      ~abjad.tools.stringtools.is_snake_case_string.is_snake_case_string
      ~abjad.tools.stringtools.is_space_delimited_lowercase_string.is_space_delimited_lowercase_string
      ~abjad.tools.stringtools.is_upper_camel_case_string.is_upper_camel_case_string
      ~abjad.tools.stringtools.pluralize_string.pluralize_string
      ~abjad.tools.stringtools.snake_case_to_lower_camel_case.snake_case_to_lower_camel_case
      ~abjad.tools.stringtools.snake_case_to_upper_camel_case.snake_case_to_upper_camel_case
      ~abjad.tools.stringtools.space_delimited_lowercase_to_upper_camel_case.space_delimited_lowercase_to_upper_camel_case
      ~abjad.tools.stringtools.string_to_accent_free_snake_case.string_to_accent_free_snake_case
      ~abjad.tools.stringtools.string_to_space_delimited_lowercase.string_to_space_delimited_lowercase
      ~abjad.tools.stringtools.strip_diacritics_from_binary_string.strip_diacritics_from_binary_string
      ~abjad.tools.stringtools.upper_camel_case_to_snake_case.upper_camel_case_to_snake_case
      ~abjad.tools.stringtools.upper_camel_case_to_space_delimited_lowercase.upper_camel_case_to_space_delimited_lowercase
